@@ -1,12 +1,12 @@
-import re
+import importlib
 import inspect
 import pathlib
-import importlib
-from typing import Union
+import re
 from datetime import datetime
+from typing import Union
 
 import datajoint as dj
-from element_interface.utils import find_root_directory, find_full_path
+from element_interface.utils import find_root_directory
 
 schema = dj.schema()
 
@@ -14,11 +14,11 @@ _linking_module = None
 
 
 def activate(
-    scan_schema_name,
+    scan_schema_name: str,
     *,
-    create_schema=True,
-    create_tables=True,
-    linking_module=None,
+    create_schema: bool = True,
+    create_tables: bool = True,
+    linking_module: str = None,
 ):
     """Activate this schema.
 
@@ -93,7 +93,7 @@ def get_processed_root_data_dir() -> Union[str, pathlib.Path]:
     locations).
 
     Returns:
-        dir (str| pathlib.Path): Absolute path of the pocessed imaging root data
+        dir (str| pathlib.Path): Absolute path of the processed imaging root data
             directory.
     """
 
@@ -161,11 +161,11 @@ class AcquisitionSoftware(dj.Lookup):
     Required to define a scan.
 
     Attributes:
-        acq_software (str): Acquistion software
+        acq_software (str): Acquisition software
     """
 
     definition = """  # Acquisition softwares
-    acq_software: varchar(24)    
+    acq_software: varchar(24)
     """
     contents = zip(["ScanImage", "Scanbox", "NIS", "PrairieView"])
 
@@ -195,7 +195,7 @@ class Scan(dj.Manual):
         Session (foreign key): A primary key from Session.
         scan_id (int): Unique Scan ID.
         Equipment (foreign key, optional): A primary key from Equipment.
-        AcquisitionSoftware (foreign key): A primary key from AcquisitonSoftware.
+        AcquisitionSoftware (foreign key): A primary key from AcquisitionSoftware.
         scan_notes (str, optional): Notes of the experimenter regarding the scan.
     """
 
@@ -219,9 +219,9 @@ class ScanLocation(dj.Manual):
     """
 
     definition = """ # Anatomical location
-    -> Scan   
+    -> Scan
     ---
-    -> Location      
+    -> Location
     """
 
 
@@ -250,7 +250,7 @@ class ScanInfo(dj.Imported):
         bidirectional_z (bool, optional): True = bidirectional z-scan.
     """
 
-    definition = """ # General data about the reso/meso scans from header
+    definition = """ # General data about the resoscans/mesoscans from header
     -> Scan
     ---
     nfields              : tinyint   # number of fields
@@ -261,7 +261,7 @@ class ScanInfo(dj.Imported):
     x=null               : float     # (um) ScanImage's 0 point in the motor coordinate system
     y=null               : float     # (um) ScanImage's 0 point in the motor coordinate system
     z=null               : float     # (um) ScanImage's 0 point in the motor coordinate system
-    fps                  : float     # (Hz) frames per second - Volumetric Scan Rate 
+    fps                  : float     # (Hz) frames per second - Volumetric Scan Rate
     bidirectional        : boolean   # true = bidirectional scanning
     usecs_per_line=null  : float     # microseconds per scan line
     fill_fraction=null   : float     # raster scan temporal fill fraction (see scanimage)
@@ -334,19 +334,13 @@ class ScanInfo(dj.Imported):
 
             # Insert in ScanInfo
             x_zero = (
-                scan.motor_position_at_zero[0]
-                if scan.motor_position_at_zero
-                else None
+                scan.motor_position_at_zero[0] if scan.motor_position_at_zero else None
             )
             y_zero = (
-                scan.motor_position_at_zero[1]
-                if scan.motor_position_at_zero
-                else None
+                scan.motor_position_at_zero[1] if scan.motor_position_at_zero else None
             )
             z_zero = (
-                scan.motor_position_at_zero[2]
-                if scan.motor_position_at_zero
-                else None
+                scan.motor_position_at_zero[2] if scan.motor_position_at_zero else None
             )
 
             self.insert1(
@@ -403,12 +397,8 @@ class ScanInfo(dj.Imported):
                             field_idx=plane_idx,
                             px_height=scan.image_height,
                             px_width=scan.image_width,
-                            um_height=getattr(
-                                scan, "image_height_in_microns", None
-                            ),
-                            um_width=getattr(
-                                scan, "image_width_in_microns", None
-                            ),
+                            um_height=getattr(scan, "image_height_in_microns", None),
+                            um_width=getattr(scan, "image_width_in_microns", None),
                             field_x=x_zero if x_zero else None,
                             field_y=y_zero if y_zero else None,
                             field_z=z_zero + scan.scanning_depths[plane_idx]
@@ -452,9 +442,7 @@ class ScanInfo(dj.Imported):
                     fps=sbx_meta["frame_rate"],
                     bidirectional=sbx_meta == "bidirectional",
                     nrois=sbx_meta["num_rois"] if is_multiROI else 0,
-                    scan_duration=(
-                        sbx_meta["num_frames"] / sbx_meta["frame_rate"]
-                    ),
+                    scan_duration=(sbx_meta["num_frames"] / sbx_meta["frame_rate"]),
                 )
             )
             # Insert Field(s)
@@ -490,13 +478,8 @@ class ScanInfo(dj.Imported):
 
             # Frame per second
             try:
-                fps = (
-                    1000
-                    / nd2_file.experiment[0]
-                    .parameters.periods[0]
-                    .periodDiff.avg
-                )
-            except:
+                fps = 1000 / nd2_file.experiment[0].parameters.periods[0].periodDiff.avg
+            except:  # noqa: E722
                 fps = 1000 / nd2_file.experiment[0].parameters.periodDiff.avg
 
             # Estimate ND2 file scan duration
@@ -516,8 +499,7 @@ class ScanInfo(dj.Imported):
                 return (tf - ti) * 86400 + 1 / fps
 
             scan_duration = sum(
-                estimate_nd2_scan_duration(nd2.ND2File(f))
-                for f in scan_filepaths
+                estimate_nd2_scan_duration(nd2.ND2File(f)) for f in scan_filepaths
             )
 
             try:
@@ -528,10 +510,8 @@ class ScanInfo(dj.Imported):
                     if re.search(("AM|PM"), scan_datetime)
                     else "%m/%d/%Y %H:%M:%S",
                 )
-                scan_datetime = datetime.strftime(
-                    scan_datetime, "%Y-%m-%d %H:%M:%S"
-                )
-            except:
+                scan_datetime = datetime.strftime(scan_datetime, "%Y-%m-%d %H:%M:%S")
+            except:  # noqa: E722
                 scan_datetime = None
 
             # Insert in ScanInfo
@@ -583,40 +563,42 @@ class ScanInfo(dj.Imported):
             from element_interface import prairieviewreader
 
             scan_filepaths = get_prairieview_files(key)
-            pvscan_info = prairieviewreader.get_pv_metadata(scan_filepaths[0])
+            PVScan_info = prairieviewreader.get_pv_metadata(scan_filepaths[0])
             self.insert1(
                 dict(
                     key,
-                    nfields=pvscan_info["num_fields"],
-                    nchannels=pvscan_info["num_channels"],
-                    ndepths=pvscan_info["num_planes"],
-                    nframes=pvscan_info["num_frames"],
-                    nrois=pvscan_info["num_rois"],
-                    x=pvscan_info["x_pos"],
-                    y=pvscan_info["y_pos"],
-                    z=pvscan_info["z_pos"],
-                    fps=pvscan_info["frame_rate"],
-                    bidirectional=pvscan_info["bidirectional"],
-                    bidirectional_z=pvscan_info["bidirectional_z"],
-                    usecs_per_line=pvscan_info["usecs_per_line"],
-                    scan_datetime=pvscan_info["scan_datetime"],
-                    scan_duration=pvscan_info["scan_duration"],
+                    nfields=PVScan_info["num_fields"],
+                    nchannels=PVScan_info["num_channels"],
+                    ndepths=PVScan_info["num_planes"],
+                    nframes=PVScan_info["num_frames"],
+                    nrois=PVScan_info["num_rois"],
+                    x=PVScan_info["x_pos"],
+                    y=PVScan_info["y_pos"],
+                    z=PVScan_info["z_pos"],
+                    fps=PVScan_info["frame_rate"],
+                    bidirectional=PVScan_info["bidirectional"],
+                    bidirectional_z=PVScan_info["bidirectional_z"],
+                    usecs_per_line=PVScan_info["usecs_per_line"],
+                    scan_datetime=PVScan_info["scan_datetime"],
+                    scan_duration=PVScan_info["scan_duration"],
                 )
             )
 
             self.Field.insert(
-                    dict(
-                        key,
-                        field_idx=plane_idx,
-                        px_height=pvscan_info["height_in_pixels"],
-                        px_width=pvscan_info["width_in_pixels"],
-                        um_height=pvscan_info["height_in_um"],
-                        um_width=pvscan_info["width_in_um"],
-                        field_x=pvscan_info["fieldX"],
-                        field_y=pvscan_info["fieldY"],
-                        field_z=pvscan_info["fieldZ"] if pvscan_info["num_planes"] == 1 else pvscan_info["fieldZ"][plane_idx],
-                    )
-                    for plane_idx in range(pvscan_info["num_planes"])
+                dict(
+                    key,
+                    field_idx=plane_idx,
+                    px_height=PVScan_info["height_in_pixels"],
+                    px_width=PVScan_info["width_in_pixels"],
+                    um_height=PVScan_info["height_in_um"],
+                    um_width=PVScan_info["width_in_um"],
+                    field_x=PVScan_info["fieldX"],
+                    field_y=PVScan_info["fieldY"],
+                    field_z=PVScan_info["fieldZ"]
+                    if PVScan_info["num_planes"] == 1
+                    else PVScan_info["fieldZ"][plane_idx],
+                )
+                for plane_idx in range(PVScan_info["num_planes"])
             )
         else:
             raise NotImplementedError(
@@ -625,12 +607,9 @@ class ScanInfo(dj.Imported):
             )
 
         # Insert file(s)
-        root_dir = find_root_directory(
-            get_imaging_root_data_dir(), scan_filepaths[0]
-        )
+        root_dir = find_root_directory(get_imaging_root_data_dir(), scan_filepaths[0])
 
         scan_files = [
-            pathlib.Path(f).relative_to(root_dir).as_posix()
-            for f in scan_filepaths
+            pathlib.Path(f).relative_to(root_dir).as_posix() for f in scan_filepaths
         ]
         self.ScanFile.insert([{**key, "file_path": f} for f in scan_files])
